package com.ruoyi.system.mapper.fgw;

import com.ruoyi.system.domain.fgw.FgwShyj;

import java.util.List;

/**
 * 发改委_审核意见Mapper接口
 * 
 * @author boman
 * @date 2023-03-22
 */
public interface FgwShyjMapper 
{
    /**
     * 查询发改委_审核意见
     * 
     * @param id 发改委_审核意见主键
     * @return 发改委_审核意见
     */
    public FgwShyj selectFgwShyjById(Long id);

    /**
     * 查询发改委_审核意见列表
     * 
     * @param fgwShyj 发改委_审核意见
     * @return 发改委_审核意见集合
     */
    public List<FgwShyj> selectFgwShyjList(FgwShyj fgwShyj);

    /**
     * 新增发改委_审核意见
     * 
     * @param fgwShyj 发改委_审核意见
     * @return 结果
     */
    public int insertFgwShyj(FgwShyj fgwShyj);

    /**
     * 修改发改委_审核意见
     * 
     * @param fgwShyj 发改委_审核意见
     * @return 结果
     */
    public int updateFgwShyj(FgwShyj fgwShyj);

    /**
     * 删除发改委_审核意见
     * 
     * @param id 发改委_审核意见主键
     * @return 结果
     */
    public int deleteFgwShyjById(Long id);

    /**
     * 批量删除发改委_审核意见
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFgwShyjByIds(Long[] ids);
}
